@@ -8,7 +8,7 @@
     'name_es_ES': 'Gestión de existencias',
     'name_fr_FR': 'Gestion des stocks',
     'name_ru_RU': 'Управление складами',
-    'version': '2.0.10',
+    'version': '2.2.0',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -114,11 +114,13 @@ Et les rapports:
         'period.xml',
     ],
     'translation': [
-        'bg_BG.csv',
-        'de_DE.csv',
-        'es_CO.csv',
-        'es_ES.csv',
-        'fr_FR.csv',
-        'ru_RU.csv',
+        'locale/cs_CZ.po',
+        'locale/bg_BG.po',
+        'locale/de_DE.po',
+        'locale/es_CO.po',
+        'locale/es_ES.po',
+        'locale/fr_FR.po',
+        'locale/nl_NL.po',
+        'locale/ru_RU.po',
     ],
 }
