@@ -1,7 +1,6 @@
 #!/usr/bin/env python
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
-from __future__ import with_statement
 
 import sys, os
 DIR = os.path.abspath(os.path.normpath(os.path.join(__file__,
@@ -15,7 +14,8 @@ from decimal import Decimal
 from dateutil.relativedelta import relativedelta
 from functools import partial
 import trytond.tests.test_tryton
-from trytond.tests.test_tryton import POOL, DB_NAME, USER, CONTEXT, test_view
+from trytond.tests.test_tryton import POOL, DB_NAME, USER, CONTEXT, test_view,\
+    test_depends
 from trytond.transaction import Transaction
 
 
@@ -42,6 +42,12 @@ class StockTestCase(unittest.TestCase):
         '''
         test_view('stock')
 
+    def test0006depends(self):
+        '''
+        Test depends.
+        '''
+        test_depends()
+
     def test0010move_internal_quantity(self):
         '''
         Test Move.internal_quantity.
@@ -106,14 +112,13 @@ class StockTestCase(unittest.TestCase):
             category_id = self.category.create({
                 'name': 'Test products_by_location',
                 })
-            kg_id, = self.uom.search([('name', '=', 'Kilogram')])
-            g_id, = self.uom.search([('name', '=', 'Gram')])
+            unit_id, = self.uom.search([('name', '=', 'Unit')])
             product_id = self.product.create({
                 'name': 'Test products_by_location',
                 'type': 'stockable',
                 'category': category_id,
                 'cost_price_method': 'fixed',
-                'default_uom': kg_id,
+                'default_uom': unit_id,
                 })
             supplier_id, = self.location.search([('code', '=', 'SUP')])
             customer_id, = self.location.search([('code', '=', 'CUS')])
@@ -130,7 +135,7 @@ class StockTestCase(unittest.TestCase):
 
             self.move.create({
                 'product': product_id,
-                'uom': kg_id,
+                'uom': unit_id,
                 'quantity': 5,
                 'from_location': supplier_id,
                 'to_location': storage_id,
@@ -143,7 +148,7 @@ class StockTestCase(unittest.TestCase):
                 })
             self.move.create({
                 'product': product_id,
-                'uom': kg_id,
+                'uom': unit_id,
                 'quantity': 1,
                 'from_location': supplier_id,
                 'to_location': storage_id,
@@ -155,7 +160,7 @@ class StockTestCase(unittest.TestCase):
                 })
             self.move.create({
                 'product': product_id,
-                'uom': kg_id,
+                'uom': unit_id,
                 'quantity': 1,
                 'from_location': storage_id,
                 'to_location': customer_id,
@@ -168,7 +173,7 @@ class StockTestCase(unittest.TestCase):
                 })
             self.move.create({
                 'product': product_id,
-                'uom': kg_id,
+                'uom': unit_id,
                 'quantity': 1,
                 'from_location': storage_id,
                 'to_location': customer_id,
@@ -180,7 +185,7 @@ class StockTestCase(unittest.TestCase):
                 })
             self.move.create({
                 'product': product_id,
-                'uom': kg_id,
+                'uom': unit_id,
                 'quantity': 2,
                 'from_location': storage_id,
                 'to_location': customer_id,
@@ -192,7 +197,7 @@ class StockTestCase(unittest.TestCase):
                 })
             self.move.create({
                 'product': product_id,
-                'uom': kg_id,
+                'uom': unit_id,
                 'quantity': 5,
                 'from_location': supplier_id,
                 'to_location': storage_id,
@@ -284,23 +289,6 @@ class StockTestCase(unittest.TestCase):
                 today + relativedelta(days=-3),
                 today + relativedelta(days=-2),
             ]
-
-            self.move.create({
-                'product': product_id,
-                'uom': g_id,
-                'quantity': 1,
-                'from_location': supplier_id,
-                'to_location': storage_id,
-                'planned_date': today + relativedelta(days=-5),
-                'effective_date': today + relativedelta(days=-5),
-                'state': 'done',
-                'company': company_id,
-                'unit_price': Decimal('1'),
-                'currency': currency_id,
-                })
-            # Nothing should change when adding a small quantity
-            test_products_by_location()
-
             for period_date in periods:
                 period_id = self.period.create({
                     'date': period_date,
